@@ -17,6 +17,7 @@ import configparser
 import logging
 import os
 import re
+import encodings
 
 from Milter.utils import parse_addr
 from collections import defaultdict
@@ -41,9 +42,25 @@ __all__ = [
     "notifications",
     "storages",
     "run",
-    "version",
     "whitelists"]
 
+__version__ = "1.0.8"
+
+
+################################################
+#  add charset alias for windows-874 encoding  #
+################################################
+
+aliases = encodings.aliases.aliases
+
+for alias in ["windows-874", "windows_874"]:
+    if alias not in aliases:
+        aliases[alias] = "cp874"
+
+setattr(encodings.aliases, "aliases", aliases)
+
+################################################
+
 
 def make_header(decoded_seq, maxlinelen=None, header_name=None,
                 continuation_ws=' ', errors='strict'):
@@ -343,7 +360,7 @@ class QuarantineMilter(Milter.Base):
             if quarantine.host_in_whitelist(hostaddr):
                 self.logger.debug(
                     f"host {hostaddr[0]} is in whitelist of "
-                    f"quarantine {quarantine['name']}")
+                    f"quarantine {quarantine.name}")
                 self.quarantines.remove(quarantine)
                 if not self.quarantines:
                     self.logger.debug(
