@@ -21,14 +21,14 @@ import sys
 import time
 
 from pyquarantine import QuarantineMilter, setup_milter
-from pyquarantine.version import __version__ as version
+from pyquarantine import __version__ as version
 
 
 def _get_quarantine(quarantines, name):
     try:
         quarantine = next((q for q in quarantines if q.name == name))
     except StopIteration:
-        raise RuntimeError(f"invalid quarantine 'name'")
+        raise RuntimeError("invalid quarantine 'name'")
     return quarantine
 
 
